@@ -2,7 +2,10 @@ import csv
 import unittest
 from contextlib import contextmanager
 from datetime import date
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 from textwrap import dedent
 
 from playhouse.csv_loader import *
@@ -107,8 +110,8 @@ class TestCSVConversion(unittest.TestCase):
             self.float_sal,
             fields=fields)
         self.assertEqual(
-            map(type, fields),
-            map(type, ModelClass._meta.get_fields()[1:]))
+            list(map(type, fields)),
+            list(map(type, ModelClass._meta.get_fields()[1:])))
         self.assertData(ModelClass, [
             (10, 'F1 L1', date(1983, 1, 1), 10000., 't'),
             (20, 'F2 L2', date(1983, 1, 2), 20000.5, 'f')])
