@@ -1,3 +1,4 @@
+#coding:utf-8
 import datetime
 import json
 import os
@@ -266,6 +267,8 @@ class PostgresExtTestCase(unittest.TestCase):
         am = self._create_am()
         am2 = ArrayModel.create(tags=['alpha', 'beta'], ints=[[1, 1]])
         am3 = ArrayModel.create(tags=['delta'], ints=[[3, 4]])
+        am4 = ArrayModel.create(tags=['中文'], ints=[[3, 4]])
+        am5 = ArrayModel.create(tags=['中文', '汉语'], ints=[[3, 4]])
 
         assertAM((Param('beta') == fn.Any(ArrayModel.tags)), am, am2)
         assertAM((Param('delta') == fn.Any(ArrayModel.tags)), am, am3)
@@ -277,10 +280,12 @@ class PostgresExtTestCase(unittest.TestCase):
         # Use the nicer API.
         assertAM(ArrayModel.tags.contains('beta'), am, am2)
         assertAM(ArrayModel.tags.contains('omega', 'delta'))
+        assertAM(ArrayModel.tags.contains('汉语'), am5)
         assertAM(ArrayModel.tags.contains('alpha', 'delta'), am)
 
         # Check for any.
         assertAM(ArrayModel.tags.contains_any('beta'), am, am2)
+        assertAM(ArrayModel.tags.contains_any('中文'), am4, am5)
         assertAM(ArrayModel.tags.contains_any('omega', 'delta'), am, am3)
         assertAM(ArrayModel.tags.contains_any('alpha', 'delta'), am, am2, am3)
 
@@ -436,6 +441,21 @@ if json_ok():
             tj_db = TestingJson.get(tj.pk_expr())
             self.assertEqual(tj_db.data, data)
 
+        def test_json_field_sql(self):
+            tj = TestingJson.select().where(TestingJson.data == {'foo': 'bar'})
+            sql, params = tj.sql()
+            self.assertEqual(sql, (
+                'SELECT t1."id", t1."data" '
+                'FROM "testingjson" AS t1 WHERE (t1."data" = %s)'))
+            self.assertEqual(params[0].adapted, {'foo': 'bar'})
+
+            tj = TestingJson.select().where(TestingJson.data['foo'] == 'bar')
+            sql, params = tj.sql()
+            self.assertEqual(sql, (
+                'SELECT t1."id", t1."data" '
+                'FROM "testingjson" AS t1 WHERE (t1."data"->>%s = %s)'))
+            self.assertEqual(params, ['foo', 'bar'])
+
         def assertItems(self, where, *items):
             query = TestingJson.select().where(where).order_by(TestingJson.id)
             self.assertEqual(
