@@ -16,7 +16,7 @@ def runtests(suite, verbosity):
 def get_option_parser():
     parser = optparse.OptionParser()
     basic = optparse.OptionGroup(parser, 'Basic test options')
-    basic.add_option('-e', '--engine', dest='engine', help='Database engine to test, one of [sqlite, postgres, mysql]')
+    basic.add_option('-e', '--engine', dest='engine', help='Database engine to test, one of [sqlite, postgres, mysql, apsw, sqlcipher]')
     basic.add_option('-v', '--verbosity', dest='verbosity', default=1, type='int', help='Verbosity of output')
 
     suite = optparse.OptionGroup(parser, 'Simple test suite options')
@@ -36,6 +36,7 @@ def get_option_parser():
     cases.add_option('--read-slave', dest='read_slave', default=False, action='store_true', help='read_slave tests')
     cases.add_option('--signals', dest='signals', default=False, action='store_true', help='signals tests')
     cases.add_option('--shortcuts', dest='shortcuts', default=False, action='store_true', help='shortcuts tests')
+    cases.add_option('--sqlcipher-ext', dest='sqlcipher', default=False, action='store_true', help='sqlcipher_ext tests (requires pysqlcipher)')
     cases.add_option('--sqlite-ext', dest='sqlite_ext', default=False, action='store_true', help='sqlite_ext tests')
     cases.add_option('--test-utils', dest='test_utils', default=False, action='store_true', help='test_utils tests')
 
@@ -53,6 +54,12 @@ def collect_modules(options):
             modules.append(tests_apsw)
         except ImportError:
             print_('Unable to import apsw tests, skipping')
+    if xtra(options.sqlcipher):
+        try:
+            from playhouse import tests_sqlcipher_ext
+            modules.append(tests_sqlcipher_ext)
+        except ImportError:
+            print_('Unable to import pysqlcipher tests, skipping')
     if xtra(options.csv):
         from playhouse import tests_csv_loader
         modules.append(tests_csv_loader)
